==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_results/mp7079_001/MP7079_AddStandardWorkOrder_001_Result.java <==

package net.datastream.schemas.mp_results.mp7079_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STDWOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7079_AddStandardWorkOrder_001_Result")
public class MP7079_AddStandardWorkOrder_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7079_AddStandardWorkOrder_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP7079_AddStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public MP7079_AddStandardWorkOrder_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7079_AddStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7079_AddStandardWorkOrder_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "standardwo"
    })
    public static class ResultData {

        @XmlElement(name = "STANDARDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected STDWOID_Type standardwo;

        /**
         * Obtient la valeur de la propriété standardwo.
         * 
         * @return
         *     possible object is
         *     {@link STDWOID_Type }
         *     
         */
        public STDWOID_Type getSTANDARDWO() {
            return standardwo;
        }

        /**
         * Définit la valeur de la propriété standardwo.
         * 
         * @param value
         *     allowed object is
         *     {@link STDWOID_Type }
         *     
         */
        public void setSTANDARDWO(STDWOID_Type value) {
            this.standardwo = value;
        }

    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_results/mp7079_001/MP7079_AddStandardWorkOrder_001_Result.java <==

package net.datastream.schemas.mp_results.mp7079_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STDWOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7079_AddStandardWorkOrder_001_Result")
public class MP7079_AddStandardWorkOrder_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7079_AddStandardWorkOrder_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7079_AddStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public MP7079_AddStandardWorkOrder_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7079_AddStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7079_AddStandardWorkOrder_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "standardwo"
    })
    public static class ResultData {

        @XmlElement(name = "STANDARDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected STDWOID_Type standardwo;

        /**
         * Gets the value of the standardwo property.
         * 
         * @return
         *     possible object is
         *     {@link STDWOID_Type }
         *     
         */
        public STDWOID_Type getSTANDARDWO() {
            return standardwo;
        }

        /**
         * Sets the value of the standardwo property.
         * 
         * @param value
         *     allowed object is
         *     {@link STDWOID_Type }
         *     
         */
        public void setSTANDARDWO(STDWOID_Type value) {
            this.standardwo = value;
        }

    }

}
